@@ -13,7 +13,7 @@ import types
 
 from . import validators
 
-__version__ = "2.5.0"
+__version__ = "2.5.1"
 
 # constants for DeletionPolicy and UpdateReplacePolicy
 Delete = 'Delete'
@@ -62,7 +62,7 @@ def encode_to_dict(obj):
         return new_lst
     elif isinstance(obj, dict):
         props = {}
-        for name, prop in obj.items():
+        for name, prop in list(obj.items()):
             props[name] = encode_to_dict(prop)
 
         return props
@@ -93,7 +93,7 @@ class BaseAWSObject(object):
         self.template = template
         self.do_validation = validation
         # Cache the keys for validity checks
-        self.propnames = self.props.keys()
+        self.propnames = list(self.props.keys())
         self.attributes = [
             'Condition', 'CreationPolicy', 'DeletionPolicy', 'DependsOn',
             'Metadata', 'UpdatePolicy', 'UpdateReplacePolicy',
@@ -117,13 +117,13 @@ class BaseAWSObject(object):
         self.__initialized = True
 
         # Check for properties defined in the class
-        for k, (_, required) in self.props.items():
+        for k, (_, required) in list(self.props.items()):
             v = getattr(type(self), k, None)
             if v is not None and k not in kwargs:
                 self.__setattr__(k, v)
 
         # Now that it is initialized, populate it with the kwargs
-        for k, v in kwargs.items():
+        for k, v in list(kwargs.items()):
             self.__setattr__(k, v)
 
         self.add_to_template()
@@ -155,7 +155,7 @@ class BaseAWSObject(object):
             raise AttributeError(name)
 
     def __setattr__(self, name, value):
-        if name in self.__dict__.keys() \
+        if name in list(self.__dict__.keys()) \
                 or '_BaseAWSObject__initialized' not in self.__dict__:
             return dict.__setattr__(self, name, value)
         elif name in self.attributes:
@@ -251,7 +251,7 @@ class BaseAWSObject(object):
             return encode_to_dict(self.resource)
         elif hasattr(self, 'resource_type'):
             d = {}
-            for k, v in self.resource.items():
+            for k, v in list(self.resource.items()):
                 if k != 'Properties':
                     d[k] = v
             return d
@@ -261,7 +261,7 @@ class BaseAWSObject(object):
     @classmethod
     def _from_dict(cls, title=None, **kwargs):
         props = {}
-        for prop_name, value in kwargs.items():
+        for prop_name, value in list(kwargs.items()):
             try:
                 prop_attrs = cls.props[prop_name]
             except KeyError:
@@ -302,7 +302,7 @@ class BaseAWSObject(object):
         return cls._from_dict(title, **d)
 
     def _validate_props(self):
-        for k, (_, required) in self.props.items():
+        for k, (_, required) in list(self.props.items()):
             if required and k not in self.properties:
                 rtype = getattr(self, 'resource_type', "<unknown type>")
                 title = getattr(self, 'title')
@@ -368,7 +368,7 @@ class AWSAttribute(BaseAWSObject):
 
 
 def validate_delimiter(delimiter):
-    if not isinstance(delimiter, basestring):
+    if not isinstance(delimiter, str):
         raise ValueError(
             "Delimiter must be a String, %s provided" % type(delimiter)
         )
@@ -498,10 +498,10 @@ class Ref(AWSHelperFn):
     def __eq__(self, other):
         if isinstance(other, self.__class__):
             return self.data == other.data
-        return self.data.values()[0] == other
+        return list(self.data.values())[0] == other
 
     def __hash__(self):
-        return hash(self.data.values()[0])
+        return hash(list(self.data.values())[0])
 
 
 # Pseudo Parameter Ref's
@@ -546,18 +546,17 @@ class Tags(AWSHelperFn):
                 elif isinstance(arg, dict):
                     tag_dict.update(arg)
                 else:
-                    raise(TypeError, "Tags needs to be either kwargs, "
-                                     "dict, or AWSHelperFn")
+                    raise TypeError
 
         def add_tag(tag_list, k, v):
             tag_list.append({'Key': k, 'Value': v, })
 
         # Detect and handle non-string Tag items which do not sort in Python3
-        if all(isinstance(k, basestring) for k in tag_dict):
+        if all(isinstance(k, str) for k in tag_dict):
             for k, v in sorted(tag_dict.items()):
                 add_tag(self.tags, k, v)
         else:
-            for k, v in tag_dict.items():
+            for k, v in list(tag_dict.items()):
                 add_tag(self.tags, k, v)
 
     # allow concatenation of the Tags object via '+' operator
@@ -575,9 +574,9 @@ class Tags(AWSHelperFn):
 
 class Template(object):
     props = {
-        'AWSTemplateFormatVersion': (basestring, False),
-        'Transform': (basestring, False),
-        'Description': (basestring, False),
+        'AWSTemplateFormatVersion': (str, False),
+        'Transform': (str, False),
+        'Description': (str, False),
         'Parameters': (dict, False),
         'Mappings': (dict, False),
         'Resources': (dict, False),
@@ -810,9 +809,9 @@ class Export(AWSHelperFn):
 
 class Output(AWSDeclaration):
     props = {
-        'Description': (basestring, False),
+        'Description': (str, False),
         'Export': (Export, False),
-        'Value': (basestring, True),
+        'Value': (str, True),
     }
 
     def add_to_template(self):
@@ -825,17 +824,17 @@ class Parameter(AWSDeclaration):
     STRING_PROPERTIES = ['AllowedPattern', 'MaxLength', 'MinLength']
     NUMBER_PROPERTIES = ['MaxValue', 'MinValue']
     props = {
-        'Type': (basestring, True),
-        'Default': ((basestring, int, float), False),
+        'Type': (str, True),
+        'Default': ((str, int, float), False),
         'NoEcho': (bool, False),
         'AllowedValues': (list, False),
-        'AllowedPattern': (basestring, False),
+        'AllowedPattern': (str, False),
         'MaxLength': (validators.positive_integer, False),
         'MinLength': (validators.positive_integer, False),
         'MaxValue': (validators.integer, False),
         'MinValue': (validators.integer, False),
-        'Description': (basestring, False),
-        'ConstraintDescription': (basestring, False),
+        'Description': (str, False),
+        'ConstraintDescription': (str, False),
     }
 
     def add_to_template(self):
@@ -866,25 +865,25 @@ class Parameter(AWSDeclaration):
             # matches (in the case of a String Type) or can be coerced
             # into one of the number formats.
             param_type = self.properties.get('Type')
-            if param_type == 'String' and not isinstance(default, basestring):
+            if param_type == 'String' and not isinstance(default, str):
                 raise ValueError(error_str %
                                  ('String', type(default), default))
             elif param_type == 'Number':
                 allowed = [float, int]
                 # See if the default value can be coerced into one
                 # of the correct types
-                if not any(map(lambda x: check_type(x, default), allowed)):
+                if not any([check_type(x, default) for x in allowed]):
                     raise ValueError(error_str %
                                      (param_type, type(default), default))
             elif param_type == 'List<Number>':
-                if not isinstance(default, basestring):
+                if not isinstance(default, str):
                     raise ValueError(error_str %
                                      (param_type, type(default), default))
                 allowed = [float, int]
                 dlist = default.split(",")
                 for d in dlist:
                     # Verify the split array are all numbers
-                    if not any(map(lambda x: check_type(x, d), allowed)):
+                    if not any([check_type(x, d) for x in allowed]):
                         raise ValueError(error_str %
                                          (param_type, type(d), dlist))
 
